@@ -26,7 +26,7 @@ class Mix(Process):
         if nvoices < 2:
             raise robox.GIParameterErr("Insufficient voices specified for the multitrack algorithm")
 
-        mute = 1.5 * (float)nextPowerOf2(nvoices)
+        mute = 1.5 * nextPowerOf2(nvoices)
 
         for ctr in range(iterations):
             audios = []
